=======
History
=======

0.3.0 (2023-01-25)
-------------------

* Fix: default matcher is not assigned for expressions without modifiers.
* Permission grants parser creates single permission matcher from list of permission grant expressions.

0.2.0 (2023-01-24)
------------------

* Full test coverage
* Structured for testability
* Permission parser

0.1.0 (2023-01-20)
------------------

* First release on PyPI.
